@@ -12,7 +12,6 @@ import socket
 import string
 import StringIO
 import sys
-import re
 
 from common import AGENT_NAME, HOST
 
@@ -32,7 +31,7 @@ class BottleClient:
 	MessageClass = mimetools.Message
 
 	def __init__(self, kanjierror="replace"):
-		self.stoc = lambda x: unicode(x, "sjis")
+		self.stoc = lambda x: unicode(x, "sjis", 'ignore')
 		self.ctos = lambda x: x.encode("sjis")
 		self.luid = ""
 		self.initialized = self.connected = 0
@@ -69,14 +68,14 @@ class BottleClient:
 		for k, v in self.headers.items():
 			self.headers[k] = self.stoc(v)
 		self.headers.headers = map(self.stoc, rawheaders)
-		return (self.headers["Result"] != "OK")
+		return (self.headers.get("Result", "") != "OK")
 	def get_new_id(self):
 		self.send_cgi_request("Command%3A+getNewId")
 		self.luid = self.headers["NewID"]
 	def get_channels(self):
 		self.send_cgi_request("Command%3A+getChannels")
 		self.channels = []
-		for i in range(int(self.headers["Count"])):
+		for i in xrange(int(self.headers["Count"])):
 			prefix = "CH%d_" % (i + 1)
 			self.channels.append({
 				"name":   self.headers[prefix + "name"],
@@ -155,7 +154,6 @@ class BottleClient:
 					print "RETRY", "*" * 70
 		if self.debug & 1:
 			open("debug.out", "a").write(data)
-		#print unicode(data, 'sjis')
 		return StringIO.StringIO(data)
 	def getreply(self):
 		self.file = self.makefile()
@@ -203,27 +201,9 @@ class BottleClient:
 			buffer.append(line)
 			if not self.strip_newline(line):
 				break
-		msg  = string.join(buffer, '')
-
-		charset = "Shift_JIS" # Default
-		mres = re.search("Charset: ?(.+?)\r\n", msg)
-		if mres is not None:
-			charset = mres.group(1)
-
-		result = ""
-		try:
-			result = unicode(msg, charset, 'ignore')
-		except UnicodeDecodeError:
-			print "Received illegal script (containing model dependence char?) ... ignoring."
-			result = None
-
-		return result
+		return string.join(buffer, '')
 	def send_sstp_message(self, message, host="localhost", port=9801):
 		buffer = []
-		try:
-			message = message.encode("sjis")
-		except UnicodeEncodeError, e:
-			raise BottleClientError("Detected illegal code: " + str(e))
 		s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 		try:
 			s.connect((host, port))
@@ -234,9 +214,7 @@ class BottleClient:
 					break
 			s.close()
 		except socket.error, (code, message):
-			#print code, message
 			return None
-		#print unicode(string.join(buffer, ''), 'utf-8')
 		return string.join(buffer, '')
 	def strip_newline(self, line):
 		if line[-2:] == "\r\n":
@@ -279,19 +257,15 @@ class BottleClient:
 			if message is None:
 				break
 			self.command, self.headers = message
-			sstp_message = self.get_sstp_message()
 			if self.command == "unicastMessage":
-				if sstp_message is not None:
-					self.handle_sstp_message(sstp_message, 1, 0)
+				self.handle_sstp_message(self.get_sstp_message(), 1, 0)
 			elif self.command == "broadcastMessage":
-				if sstp_message is not None:
-					self.handle_sstp_message(sstp_message, 0, 0)
+				self.handle_sstp_message(self.get_sstp_message(), 0, 0)
 			elif self.command == "forceBroadcastMessage":
-				if sstp_message is not None:
-					self.handle_sstp_message(sstp_message, 0, 1)
-					message = self.headers.get("DialogMessage")
-					if message:
-						self.handle_dialog_message(message)
+				self.handle_sstp_message(self.get_sstp_message(), 0, 1)
+				message = self.headers.get("DialogMessage")
+				if message:
+					self.handle_dialog_message(message)
 			elif self.command == "broadcastInformation":
 				self.handle_broadcast_information(self.headers["Type"], 0)
 			elif self.command == "forceBroadcastInformation":
@@ -301,18 +275,18 @@ class BottleClient:
 				self.handle_all_users()
 			elif self.command == "channelUsers":
 				name = self.headers["Channel"]
-				for i in range(len(self.channels)):
+				for i in xrange(len(self.channels)):
 					if self.channels[i]["name"] == name:
 						self.channels[i]["count"] = int(self.headers["Num"])
 						self.handle_channel_users(i)
 			elif self.command == "closeChannel":
 				name = self.headers["Channel"]
-				for n in range(len(self.channels)):
+				for n in xrange(len(self.channels)):
 					if self.channels[n]["name"] == name:
 						del self.channels[n]
 						if n in self.in_channels:
 							self.in_channels.remove(n)
-						for i in range(len(self.in_channels)):
+						for i in xrange(len(self.in_channels)):
 							if self.in_channels[i] > n:
 								self.in_channels[i] = self.in_channels[i] - 1
 						self.handle_close_channel(name)
@@ -414,7 +388,7 @@ def test():
 		print "Users:", client.users
 	if list_channels:
 		perm = {0: "", 1: " (receive only)"}
-		for i in range(len(client.channels)):
+		for i in xrange(len(client.channels)):
 			dict = client.channels[i]
 			print "%d: %s%s" % (i, dict["name"], perm[dict["nopost"]])
 			print "  ", dict["info"]
