@@ -11,12 +11,17 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: common.py,v 1.30 2005/09/09 19:09:05 atzm Exp $
+# $Id: common.py,v 1.31 2006/01/07 21:03:51 atzm Exp $
 #
 
 import os, sys
 import gtk
 
+try:
+	set, frozenset
+except NameError:
+	from sets import Set as set, ImmutableSet as frozenset
+
 # common defines
 APP = 'GBottler'
 VER = '0.1.5'
@@ -65,6 +70,9 @@ WAIT_NEXT_REQUEST = 20
 WAIT_NEXT_LOCALGHOST_POLL = 30000
 
 # common functions
+def uniq(sequence):
+	return list(set(sequence))
+
 def open_bottlecase(path=None):
 	libdir = os.path.expanduser(path or LIBDIR)
 	if not os.path.exists(libdir):
