@@ -13,7 +13,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: gbottler.py,v 1.179 2005/09/28 01:19:45 atzm Exp $
+# $Id: gbottler.py,v 1.181 2008/05/16 20:43:48 atzm Exp $
 #
 
 import os, sys, string, re, gettext, getopt
@@ -117,7 +117,7 @@ class Application:
 			('GViewer', None, _('GViewer'), None, _('Open GViewer window'), self.open_gviewer),
 			('SVGManager', None, _('SVGManager'), None, _('Open SVGManager window'), lambda x: self.svgmanager.open(x)),
             ('Help', None, _('_Help')),
-            ('About', gtk.STOCK_DIALOG_INFO, _('About'), None, _('About GBottler'), self.about),
+            ('About', gtk.STOCK_ABOUT, _('About'), None, _('About GBottler'), self.about),
             ])
 		self.action_group.add_toggle_actions([
 			('HidePhraseBar', None, _('Hide phrase bar'), None, _('Hide phrase bar'), lambda x: self.phrase_bar.set_property('visible', not x.get_active())),
@@ -454,7 +454,12 @@ class Application:
 		self.users.set_text('')
 
 	def update_channel(self, widget=None, *args):
-		self.show_users_of(self.get_channel_id())
+		try:
+			_id = self.get_channel_id()
+		except RuntimeError:
+			# disable_channel() clears channel_combo
+			return
+		self.show_users_of(_id)
 		self.check_channel_permission()
 
 	def close_channel(self, name):
@@ -479,14 +484,9 @@ class Application:
 		raise RuntimeError, "unknown channel name (%s)" % name
 
 	def uniq_ghosts(self, misc=[]):
-		ghosts = misc + self.local_ghost + self.svgmanager.get_fmo_ghostnames()
-		for ghostname in ghosts:
-			if not ghostname:
-				while ghosts.count(ghostname):
-					ghosts.remove(ghostname)
-			else:
-				while ghosts.count(ghostname) - 1:
-					ghosts.remove(ghostname)
+		ghosts = uniq(misc + self.local_ghost + self.svgmanager.get_fmo_ghostnames())
+		while ghosts.count(''):
+			ghosts.remove('')
 		return ghosts
 
 	def get_index_from_liststore(self, model, text):
