@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: localmessenger.py,v 1.17 2004/10/01 22:16:55 atzm Exp $
+# $Id: localmessenger.py,v 1.18 2005/08/29 19:03:24 atzm Exp $
 #
 
 import string, StringIO, re, time, socket
@@ -32,7 +32,7 @@ class LocalMessageSender(Thread):
 		self.setDaemon(True)
 
 	def play_cancel_page_of(self, list):
-		for i in range(len(self.message_queue)):
+		for i in xrange(len(self.message_queue)):
 			if self.message_queue[i][2] is list:
 				del self.message_queue[i]
 				self.play_cancel_page_of(list)
@@ -208,7 +208,7 @@ class LocalMessenger:
 		if not charset:
 			charset = 'sjis'
 
-		for i in range(len(names)):
+		for i in xrange(len(names)):
 			names[i] = unicode(names[i], charset)
 
 		if command == 'GetNames':
