@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logwindow.py,v 1.36 2005/09/21 12:04:46 atzm Exp $
+# $Id: logwindow.py,v 1.37 2007/09/14 19:07:32 atzm Exp $
 #
 
 import gtk, gobject
@@ -737,7 +737,7 @@ class LogWindow:
 		self.textmanager.insert_with_color_from(script)
 		self.sw2.emit('scroll-child', gtk.SCROLL_START, False)
 		self.sbar.pop(0)
-		self.sbar.push(0, str(len(script.encode('sjis'))) + unicode(_('bytes'), 'utf-8'))
+		self.sbar.push(0, str(len(script.encode('sjis', 'xmlcharrefreplace'))) + unicode(_('bytes'), 'utf-8'))
 		self.update_select_no(loglist)
 
 	def scroll(self, widget, event):
