@@ -10,15 +10,15 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: messagesender.py,v 1.4 2004/09/29 21:58:11 atzm Exp $
+# $Id: messagesender.py,v 1.6 2005/09/08 20:03:43 atzm Exp $
 #
 
 import gtk
 import os, sys, time
 from threading import Thread
 from common import *
-
 from bottlelib import BottleClientError
+import config
 
 if os.name == 'posix':
 	import fcntl
@@ -35,7 +35,7 @@ class VoteMessageSender(Thread):
 
 	def run(self):
 		gtk.gdk.threads_enter()
-		self.logwindow.set_message(unicode(_('Sending %s Message...' % self.type), 'utf-8'))
+		self.logwindow.set_message(unicode(_('Sending %s Message...') % self.type, 'utf-8'))
 		gtk.gdk.flush()
 		gtk.gdk.threads_leave()
 
@@ -53,11 +53,9 @@ class VoteMessageSender(Thread):
 
 
 class MessageSender(Thread):
-	def __init__(self, app, client, auto_clear, logging, channel, script, ghost):
+	def __init__(self, app, client, channel, script, ghost):
 		self.app        = app
 		self.client     = client
-		self.auto_clear = auto_clear
-		self.logging    = logging
 		self.channel    = channel
 		self.script     = script
 		self.ghost      = ghost
@@ -98,9 +96,9 @@ class MessageSender(Thread):
 				gtk.gdk.flush()
 				gtk.gdk.threads_leave()
 
-			if self.auto_clear:
+			if config.get('general', 'auto_reset_editor', 'boolean'):
 				gtk.gdk.threads_enter()
-				self.app.edit_clear()
+				self.app.edit_reset()
 				gtk.gdk.flush()
 				gtk.gdk.threads_leave()
 
@@ -110,7 +108,7 @@ class MessageSender(Thread):
 		gtk.gdk.threads_leave()
 
 	def sent_log(self):
-		if not self.logging:
+		if not config.get('general', 'logging_sent_script', 'boolean'):
 			return True
 
 		now     = time.strftime("%Y/%m/%d-%H:%M:%S", time.localtime(time.time()))
