@@ -10,11 +10,11 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: preferences.py,v 1.6 2005/09/27 21:35:42 atzm Exp $
+# $Id: preferences.py,v 1.7 2008/05/18 08:03:28 atzm Exp $
 #
 
 __author__ = '$Author: atzm $'
-__version__ = '$Revision: 1.6 $'
+__version__ = '$Revision: 1.7 $'
 
 import gtk, gobject
 
@@ -39,6 +39,7 @@ class PreferenceDialog(gtk.Dialog):
 
 		items = []
 		items.append([_('General')] + self.__create_general_page())
+		items.append([_('Key')] + self.__create_key_page())
 		items.append([_('Logs')] + self.__create_log_page())
 		items.append([_('Network')] + self.__create_network_page())
 		items.append([_('Fonts')] + self.__create_font_page())
@@ -242,6 +243,91 @@ class PreferenceDialog(gtk.Dialog):
 		scriptframe.add(scriptbox)
 		return scriptframe, scriptdic
 
+	def __create_key_page(self):
+		keframe, kedic   = self.__create_key_enter_frame()
+		kseframe, ksedic = self.__create_key_shift_enter_frame()
+		kceframe, kcedic = self.__create_key_ctrl_enter_frame()
+		kaeframe, kaedic = self.__create_key_alt_enter_frame()
+
+		key_page_dict = OrderedDictionary()
+		key_page_dict['key'] = kedic
+		key_page_dict['key'].update(ksedic)
+		key_page_dict['key'].update(kcedic)
+		key_page_dict['key'].update(kaedic)
+
+		key_page = gtk.VBox()
+		for widget in [keframe, kseframe, kceframe, kaeframe]:
+			key_page.pack_start(widget, False, False, 0)
+		return [key_page, key_page_dict]
+
+	def __create_key_enter_frame(self):
+		kedic = OrderedDictionary()
+		kedic['enter'] = gtk.combo_box_new_text()
+		kedic['enter'].append_text(_(r'Insert "\n"'))
+		kedic['enter'].append_text(_(r'Insert "\n" and Newline'))
+		kedic['enter'].append_text(_('Insert Newline'))
+
+		vbox = gtk.VBox()
+		vbox.set_border_width(5)
+		vbox.pack_start(kedic['enter'])
+
+		frame = gtk.Frame(_('Action on Enter Key Pressed'))
+		frame.set_border_width(5)
+		frame.add(vbox)
+
+		return frame, kedic
+
+	def __create_key_shift_enter_frame(self):
+		ksedic = OrderedDictionary()
+		ksedic['shift_enter'] = gtk.combo_box_new_text()
+		ksedic['shift_enter'].append_text(_(r'Insert "\n"'))
+		ksedic['shift_enter'].append_text(_(r'Insert "\n" and Newline'))
+		ksedic['shift_enter'].append_text(_('Insert Newline'))
+
+		vbox = gtk.VBox()
+		vbox.set_border_width(5)
+		vbox.pack_start(ksedic['shift_enter'])
+
+		frame = gtk.Frame(_('Action on Shift+Enter Key Pressed'))
+		frame.set_border_width(5)
+		frame.add(vbox)
+
+		return frame, ksedic
+
+	def __create_key_ctrl_enter_frame(self):
+		kcedic = OrderedDictionary()
+		kcedic['ctrl_enter'] = gtk.combo_box_new_text()
+		kcedic['ctrl_enter'].append_text(_(r'Insert "\n"'))
+		kcedic['ctrl_enter'].append_text(_(r'Insert "\n" and Newline'))
+		kcedic['ctrl_enter'].append_text(_('Insert Newline'))
+
+		vbox = gtk.VBox()
+		vbox.set_border_width(5)
+		vbox.pack_start(kcedic['ctrl_enter'])
+
+		frame = gtk.Frame(_('Action on Ctrl+Enter Key Pressed'))
+		frame.set_border_width(5)
+		frame.add(vbox)
+
+		return frame, kcedic
+
+	def __create_key_alt_enter_frame(self):
+		kaedic = OrderedDictionary()
+		kaedic['alt_enter'] = gtk.combo_box_new_text()
+		kaedic['alt_enter'].append_text(_(r'Insert "\n"'))
+		kaedic['alt_enter'].append_text(_(r'Insert "\n" and Newline'))
+		kaedic['alt_enter'].append_text(_('Insert Newline'))
+
+		vbox = gtk.VBox()
+		vbox.set_border_width(5)
+		vbox.pack_start(kaedic['alt_enter'])
+
+		frame = gtk.Frame(_('Action on Alt+Enter Key Pressed'))
+		frame.set_border_width(5)
+		frame.add(vbox)
+
+		return frame, kaedic
+
 	def __create_log_page(self):
 		loggingframe, loggingdic = self.__create_logging_frame()
 		lognewtabframe, lognewwindic = self.__create_logwindow_frame()
