@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: showingsurface.py,v 1.11 2005/08/29 19:03:24 atzm Exp $
+# $Id: showingsurface.py,v 1.12 2008/05/16 20:43:48 atzm Exp $
 #
 
 import gtk, pango
@@ -29,7 +29,7 @@ class ShowingSurface:
 		h = self.height  / SIZE_SURFACE_V
 		splite = (y * w) + x
 		try:
-			self.app.insert(r'\s[%d]' % self.ghost.reverse_dic[splite])
+			self.app.insert(self, r'\s[%d]' % self.ghost.reverse_dic[splite])
 		except:
 			pass
 
