@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: svgmanager.py,v 1.47 2005/09/08 21:19:57 atzm Exp $
+# $Id: svgmanager.py,v 1.49 2008/05/22 12:31:08 atzm Exp $
 
 import gtk, gobject
 import os, sys, shutil
@@ -33,7 +33,7 @@ class SVGManagerWindow(gtk.Window):
 		## Create GhostList window
 
 		self.ghost_list_str = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING,
-									gobject.TYPE_STRING,  gobject.TYPE_STRING)
+									gobject.TYPE_BOOLEAN,  gobject.TYPE_STRING)
 
 		self.ghost_list = gtk.TreeView(self.ghost_list_str)
 		self.ghost_list.set_enable_search(True)
@@ -63,6 +63,11 @@ class SVGManagerWindow(gtk.Window):
 				cell.connect("toggled", self.check_use_toggle)
 				columns[i].pack_start(cell, True)
 				columns[i].add_attribute(cell, 'active', i)
+			elif i == 2:
+				cell = gtk.CellRendererToggle()
+				cell.connect("toggled", self.check_fmo_toggle)
+				columns[i].pack_start(cell, True)
+				columns[i].add_attribute(cell, 'active', i)
 			else:
 				cell = gtk.CellRendererText()
 				columns[i].pack_start(cell, True)
@@ -243,7 +248,7 @@ class SVGManagerWindow(gtk.Window):
 			rng = range(current+1, len(self.ghost_list_str))
 
 		for i in rng:
-			for j in xrange(1, 3):
+			for j in [1, 3]:
 				m = pat.search(self.ghost_list_str.get_value(self.ghost_list_str.get_iter(i), j))
 				if m:
 					self.ghost_list.set_cursor(i)
@@ -506,7 +511,7 @@ class SVGManagerWindow(gtk.Window):
 			i = self.ghost_list.get_cursor()[0][0]
 			now = self.ghost_list.get_selection()
 			[model, iter] = now.get_selected()
-			if model.get_value(iter, 2) == 'FMO':
+			if model.get_value(iter, 2):
 				self.delete_fmo(model, iter)
 			else:
 				self.set_fmo(model, iter)
@@ -566,6 +571,17 @@ class SVGManagerWindow(gtk.Window):
 		except:
 			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
 
+	def check_fmo_toggle(self, cellrenderer, path):
+		model = self.ghost_list_str
+		iter = model.get_iter(path)
+		try:
+			if self.ghost_list_str.get_value(iter, 2):
+				self.delete_fmo(model, iter)
+			else:
+				self.set_fmo(model, iter)
+		except:
+			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
+
 	def url_jump(self, button, hpurl):
 		try:
 			os.system(config.get('browser', 'browser_command') % hpurl + ' &')
@@ -599,11 +615,11 @@ class SVGManagerWindow(gtk.Window):
 
 	def set_fmo(self, model, iter):
 		## insert 'FMO' the third item
-		self.ghost_list_str.set_value(iter, 2, 'FMO')
+		self.ghost_list_str.set_value(iter, 2, True)
 
 	def delete_fmo(self, model, iter):
 		## delete 'FMO' the third item 'FMO'
-		self.ghost_list_str.set_value(iter, 2, '')
+		self.ghost_list_str.set_value(iter, 2, False)
 
 if __name__ == "__main__":
 	sm = SVGManagerWindow()
