@@ -10,12 +10,12 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: textmanager.py,v 1.38 2005/09/08 20:03:43 atzm Exp $
+# $Id: textmanager.py,v 1.41 2008/05/18 18:07:30 atzm Exp $
 #
 
 import os
 import sys
-import gtk, pango
+import gobject, gtk, pango
 
 from bottleparser import *
 from types import *
@@ -23,6 +23,10 @@ from common import *
 import config
 
 class TextManager(gtk.TextView):
+	__gsignals__ = {
+		'enter-pressed': (gobject.SIGNAL_RUN_LAST|gobject.SIGNAL_ACTION, gobject.TYPE_NONE, (gobject.TYPE_INT,))
+	}
+
 	def __init__(self, app, parser=BottleParser('loose')):
 		gtk.TextView.__init__(self)
 
@@ -54,6 +58,23 @@ class TextManager(gtk.TextView):
 		# initialize
 		self.receive_preferences_changed()
 
+	def do_enter_pressed(self, modifier):
+		if modifier == gtk.gdk.SHIFT_MASK:
+			action = config.get('key', 'shift_enter', 'int')
+		elif modifier == gtk.gdk.CONTROL_MASK:
+			action = config.get('key', 'ctrl_enter', 'int')
+		elif modifier == gtk.gdk.MOD1_MASK:
+			action = config.get('key', 'alt_enter', 'int')
+		else:
+			action = config.get('key', 'enter', 'int')
+
+		if action == config.KEY_ENTER_BACKSLASH_N:
+			self.emit('insert-at-cursor', r'\n')
+		elif action == config.KEY_ENTER_BACKSLASH_N_NEWLINE:
+			self.emit('insert-at-cursor', '\\n\n')
+		elif action == config.KEY_ENTER_NEWLINE:
+			self.emit('insert-at-cursor', '\n')
+
 	def color_changed(self, over_color='light gray'):
 		tag_table = self.textbuffer.get_tag_table()
 
@@ -198,9 +219,9 @@ class TextManager(gtk.TextView):
 		#self.textbuffer.insert(self.textbuffer.get_end_iter(), '\n')
 		if end != pos:
 			if end != 0:
-				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, end*-1, False)
+				self.emit('move-cursor', gtk.MOVEMENT_LOGICAL_POSITIONS, end*-1, False)
 			if pos != 0:
-				self.emit('move-cursor', gtk.MOVEMENT_VISUAL_POSITIONS, pos, False)
+				self.emit('move-cursor', gtk.MOVEMENT_LOGICAL_POSITIONS, pos, False)
 
 	def insert_with_color_from(self, string, pos=-3):
 		current = ['sakura'] # tag stack for closable (currently only synchronized) sessions
@@ -300,7 +321,7 @@ class TextManager(gtk.TextView):
 		self.textbuffer.apply_tag_by_name('font', si, ei)
 
 		if pos != 0:
-			self.emit("move-cursor", gtk.MOVEMENT_VISUAL_POSITIONS, pos, False)
+			self.emit("move-cursor", gtk.MOVEMENT_LOGICAL_POSITIONS, pos, False)
 
 	def set_style_talk(self):
 		self.view_style = STYLE_TALK
@@ -330,3 +351,17 @@ class TextManager(gtk.TextView):
 
 	def get_buffer(self):
 		return self.textbuffer
+
+gobject.type_register(TextManager)
+
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.Return, 0, 'enter-pressed', gobject.TYPE_INT, 0)
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.KP_Enter, 0, 'enter-pressed', gobject.TYPE_INT, 0)
+
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.Return, gtk.gdk.SHIFT_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.SHIFT_MASK)
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.KP_Enter, gtk.gdk.SHIFT_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.SHIFT_MASK)
+
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.Return, gtk.gdk.CONTROL_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.CONTROL_MASK)
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.KP_Enter, gtk.gdk.CONTROL_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.CONTROL_MASK)
+
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.Return, gtk.gdk.MOD1_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.MOD1_MASK)
+gtk.binding_entry_add_signal(TextManager, gtk.keysyms.KP_Enter, gtk.gdk.MOD1_MASK, 'enter-pressed', gobject.TYPE_INT, gtk.gdk.MOD1_MASK)
