@@ -11,10 +11,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghostmanager.py,v 1.28 2005/09/27 05:59:49 atzm Exp $
+# $Id: ghostmanager.py,v 1.29 2007/09/15 09:02:26 atzm Exp $
 #
 
-__version__ = '$Revision: 1.28 $'
+__version__ = '$Revision: 1.29 $'
 __author__ = '$Author: atzm $'
 
 import gobject
@@ -216,12 +216,11 @@ class GhostManager:
 			[define, name, fmo, path] = list[i]
 
 			name = self.unicoding(name)
-			fmo  = self.unicoding(fmo)
 			path = self.unicoding(path)
 
 			self.ghost_dic[path] = [define, name, fmo, path]
 			if define:
-				if fmo[:3] == 'FMO':
+				if fmo:
 					fmoghost = self.nominate_ghost_txt(os.path.basename(expand_quote(path)))
 					if fmoghost is not None:
 						fmoghostname = fmoghost.get_sakura()
@@ -231,6 +230,11 @@ class GhostManager:
 			else:
 				define = '#GHOST'
 
+			if fmo:
+				fmo = "FMO"
+			else:
+				fmo = ""
+
 			path = path.replace('/', '\\')
 			line = string.join([define, name, fmo, path], ',').encode('sjis')
 			file.write(line + '\r\n')
@@ -280,12 +284,17 @@ class GhostManager:
 			else:
 				define = False
 
+			if fmo[:3] == "FMO":
+				fmo = True
+			else:
+				fmo = False
+
 			path = os.path.normpath(path.replace('\\', r'/'))
 			ghostname = unicode(ghostname, 'sjis', 'replace')
 			self.ghost_dic[path] = [define, ghostname, fmo, path]
 
 			expanded_path = expand_quote(path)
-			if fmo[:3] == "FMO" and define and os.path.isfile(os.path.join(base_dir, expanded_path)):
+			if fmo and define and os.path.isfile(os.path.join(base_dir, expanded_path)):
 				ghost = self.nominate_ghost_txt(os.path.basename(expanded_path))
 				if ghost is not None:
 					name = ghost.get_sakura()
